@@ -1,19 +1,25 @@
 import argparse
 import logging
 import os
-
 import django
 
-from cleargrid.logging import add_log_file
-from cleargrid.mc3_integration.runner import Runner
-from cleargrid.mc3_integration.updater import Updater
-
 os.environ.setdefault(
     "DJANGO_SETTINGS_MODULE", "cleargrid.mc3_integration.settings"
 )
 django.setup()
 
-FORMAT="%(asctime)s - %(filename)12s:%(lineno)4d - %(threadName)10s[%(levelname)7s]:%(message)s"
+
+from cleargrid.logging import add_log_file  # noqa
+from cleargrid.mc3_integration.runner import Runner  # noqa
+from cleargrid.mc3_integration.updater import Updater  # noqa
+
+
+FORMAT = (
+    "%(asctime)s - %(filename)12s:%(lineno)4d - "
+    "%(threadName)10s[%(levelname)7s]:%(message)s"
+)
+
+
 class StdoutUpdater(Updater):
     def post(self, *args, **kwargs):
         print(f"POST: {args[0]}")
@@ -54,8 +60,7 @@ def main():
     args = parser.parse_args()
 
     logging.basicConfig(
-        format=FORMAT,
-        level=getattr(logging, args.log_level.upper(), "INFO"),
+        format=FORMAT, level=getattr(logging, args.log_level.upper(), "INFO"),
     )
     add_log_file(args.log_file, "mc3_integrations")
 
