@@ -15,17 +15,19 @@ def define_db():
     }
     username = get_setting("DB_USERNAME", None)
     password = get_setting("DB_PASSWORD", None)
-    options = get_setting("OPTIONS", {"driver": "ODBC Driver 11 for SQL Server"})
-    host = get_setting("DB_HOST",  "\\".join(["127.0.0.1", "ITRONMC"]))
+    options = get_setting(
+        "OPTIONS", {"driver": "ODBC Driver 11 for SQL Server"}
+    )
+    host = get_setting("DB_HOST", "\\".join(["127.0.0.1", "ITRONMC"]))
 
     if username is not None:
         config.update(USER=username)
     if password is not None:
         config.update(PASSWORD=password)
-    if options is not None: 
+    if options is not None:
         config.update(OPTIONS=options)
     config.update(HOST=host)
-    
+
     return config
 
 
@@ -34,7 +36,7 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 # DJANGO: PRODUCTION DATABASE
 DATABASES = {"default": define_db()}
 
-INSTALLED_APPS = ("mc3_integration.data",)
+INSTALLED_APPS = ("cleargrid.mc3_integration.data",)
 
 SECRET_KEY = "fly@123"
 
